Body

Struct Body 

pub struct Body(/* private fields */);
A HTTP Body.

Construct this HTTP body using:

  • Body::empty for the empty body, or impl From<()> for Body
  • From<&[u8]> (which will make a clone) or From<Vec<u8>> or From<Bytes> for a Body from bytes.
  • From<&str> (which will make a clone) or From<String> for a Body from strings.
  • Body::from_json for a Body from a Serialize (requires feature json)
  • From<AsyncInputStream> for a Body with contents given by the contents of a WASI input-stream.
  • Body::from_stream or Body::from_try_stream for a Body from a Stream of Into<Bytes>

Consume this HTTP body using:

  • Body::into_boxed_body converts it to an UnsyncBoxBody<Bytes, Error>. This is a boxed representation of http_body::Body that is Send but not Sync. The Unsync variant is required for compatibility with the axum crate.
  • async fn Body::contents(&mut self) -> Result<&[u8], Error> is ready when all contents of the body have been collected, and gives them as a byte slice.
  • async fn Body::bytes_contents(&mut self) -> Result<Bytes, Error> is the same as Body::contents, except returns the Bytes type instead of a byte slice.
  • async fn Body::str_contents(&mut self) -> Result<&str, Error> is ready when all contents of the body have been collected, and gives them as a str slice.
  • async fn Body::json(&mut self) -> Result<T, Error> gathers body contents and then uses T: serde::Deserialize to deserialize to json (requires feature json).

Implementations

Source

impl Body

pub fn into_boxed_body(self) -> UnsyncBoxBody<Bytes, Error>

Convert this Body into an UnsyncBoxBody<Bytes, Error>, which exists to implement the http_body::Body trait. Consume the contents using http_body_utils::BodyExt, or anywhere else an impl of http_body::Body is accepted.

pub async fn contents(&mut self) -> Result<&[u8], Error>

Collect the entire contents of this Body, and expose them as a byte slice. This async fn will be pending until the entire Body is copied into memory, or an error occurs.

pub async fn bytes_contents(&mut self) -> Result<Bytes, Error>

Collect the entire contents of this Body, and expose it as Bytes. This async fn will be pending until the entire Body is copied into memory, or an error occurs.

pub fn content_length(&self) -> Option<u64>

Get a value for the length of this Body’s content, in bytes, if known. This value can come from either the Content-Length header received in the incoming request or response assocated with the body, or be provided by an exact http_body::Body::size_hint if the Body is constructed from an http_body::Body impl.

pub fn empty() -> Self

Construct an empty Body

pub async fn str_contents(&mut self) -> Result<&str, Error>

Collect the entire contents of this Body, and expose them as a string slice. This async fn will be pending until the entire Body is copied into memory, or an error occurs. Additonally errors if the contents of the Body were not a utf-8 encoded string.

pub fn from_json<T: Serialize>(data: &T) -> Result<Self, Error>

Construct a Body by serializing a type to json. Can fail with a serde_json::Error if serilization fails.

pub async fn json<T: for<'a> Deserialize<'a>>(&mut self) -> Result<T, Error>

Collect the entire contents of this Body, and deserialize them from json. Can fail if the body contents are not utf-8 encoded, are not valid json, or the json is not accepted by the serde::Deserialize impl.

pub fn from_stream<S>(stream: S) -> Self
where S: Stream + Send + 'static, <S as Stream>::Item: Into<Bytes>,

Construct a Body backed by a futures_lite::Stream impl. The stream will be polled as the body is sent.

pub fn from_try_stream<S, D, E>(stream: S) -> Self
where S: Stream<Item = Result<D, E>> + Send + 'static, D: Into<Bytes>, E: Error + Send + Sync + 'static,

Construct a Body backed by a futures_lite::Stream impl. The stream will be polled as the body is sent. If the stream gives an error, the body will canceled, which closes the underlying connection.

pub fn from_http_body<B>(http_body: B) -> Self
where B: HttpBody + Send + 'static, <B as HttpBody>::Data: Into<Bytes>, <B as HttpBody>::Error: Into<Error>,

Construct a Body backed by a http_body::Body. The http_body will be polled as the body is sent. If the http_body poll gives an error, the body will be canceled, which closes the underlying connection.

Note, this is the only constructor which permits adding trailers to the Body.